@@ -124,9 +124,11 @@ Accounting stuff
     ana
     sheets
 
-Differentiator packages
+Plugin namespaces
 =======================
 
+(See :ref:`plugin_namespaces`).
+
 .. autosummary::
    :toctree:
 
