@@ -1,8 +1,7 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2018 Rumma & Ko Ltd
+# Copyright 2012-2020 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
-# from decimal import Decimal
 from lino_xl.lib.ledger.utils import ZERO, ONE
 
 from django.db import models
@@ -33,10 +32,10 @@ from lino_xl.lib.contacts.mixins import ContactRelated
 
 from lino.utils.dates import DateRangeValue
 
-from .choicelists import EnrolmentStates, CourseStates, CourseAreas
+from .choicelists import EnrolmentStates, CourseStates, ActivityLayouts
 from .actions import PrintPresenceSheet
 
-cal = dd.resolve_app('cal')
+cal = dd.resolve_app('cal')  # returns None if cal is not imported
 
 try:
     teacher_model = dd.plugins.courses.teacher_model
@@ -66,7 +65,6 @@ class StartEndTime(dd.Model):
         verbose_name=_("End Time"))
 
 
-
 class Slot(mixins.Sequenced, StartEndTime):
 
     class Meta:
@@ -99,15 +97,13 @@ class Line(Referrable, Duplicable, ExcerptTitle, ContactRelated):
         verbose_name = pgettext("singular form", "Activity line")
         verbose_name_plural = pgettext("plural form", 'Activity lines')
 
-    course_area = CourseAreas.field(default='default')
-    # default=CourseAreas.get_lazy('default')
+    course_area = ActivityLayouts.field(default='default')
+    # default=ActivityLayouts.get_lazy('default')
     topic = dd.ForeignKey(Topic, blank=True, null=True)
     description = dd.BabelTextField(_("Description"), blank=True)
 
     every_unit = Recurrencies.field(
-        _("Recurrency"),
-        default=Recurrencies.as_callable('weekly'),
-        blank=True)  # iCal:DURATION
+        _("Recurrency"), default='weekly', blank=True)
     every = models.IntegerField(_("Repeat every"), default=1)
 
     event_type = dd.ForeignKey(
@@ -181,7 +177,6 @@ class Course(Reservation, Duplicable, Printable):
         # verbose_name = _("Event")
         # verbose_name_plural = _('Events')
 
-
     site_field_name = 'room'
 
     # line = dd.ForeignKey('courses.Line', null=True, blank=True)
@@ -264,8 +259,6 @@ class Course(Reservation, Duplicable, Printable):
 
         if self.room is None:
             return "%s (%s)" % (line, dd.fds(self.start_date))
-        # Note that we cannot use super() with
-        # python_2_unicode_compatible
         return "%s (%s %s)" % (line, dd.fds(self.start_date),self.room)
 
     def get_detail_action(self, ar):
@@ -300,7 +293,8 @@ class Course(Reservation, Duplicable, Printable):
         return self.start_date
 
     def update_cal_event_type(self):
-        return self.line.event_type
+        if self.line_id:
+            return self.line.event_type
 
     def update_cal_summary(self, et, i):
         if self.every_unit == Recurrencies.once:
@@ -320,18 +314,18 @@ class Course(Reservation, Duplicable, Printable):
         """Look up enrolments of this course and suggest them as guests."""
         # logger.info("20140314 suggest_guests")
         Enrolment = rt.models.courses.Enrolment
-        if self.line is None:
-            return
-        gr = self.line.guest_role
-        if gr is None:
-            return
+        # if self.line is None:
+        # if self.line_id is None:
+        #     return
+        # gr = self.line.guest_role or settings.SITE.pupil_guestrole
+        # if gr is None:
+        #     return
         # fkw = dict(course=self)
         # states = (EnrolmentStates.requested, EnrolmentStates.confirmed)
         # fkw.update(state__in=states)
         qs = Enrolment.objects.filter(course=self).order_by(
             *[f.name for f in Enrolment.quick_search_fields])
         for obj in qs:
-            # if obj.is_guest_for(event):
             g = obj.make_guest_for(event)
             if g is not None:
                 yield g
@@ -403,9 +397,10 @@ class Course(Reservation, Duplicable, Printable):
 
     @dd.displayfield(_("Calendar entries"))
     def events_text(self, ar=None):
-        return ', '.join([
-            day_and_month(e.start_date)
-            for e in self.events_by_course().order_by('start_date')])
+        if cal is not None:
+            return ', '.join([
+                day_and_month(e.start_date)
+                for e in self.events_by_course().order_by('start_date')])
 
     def events_by_course(self, **kwargs):
         ct = rt.models.contenttypes.ContentType.objects.get_for_model(
@@ -473,22 +468,21 @@ class Course(Reservation, Duplicable, Printable):
         return rt.models.courses.EnrolmentsByCourse.request(
             self, param_values=pv)
 
-    @dd.virtualfield(dd.HtmlBox(_("Presences")))
-    def presences_box(self, ar):
-        # not finished
-        if ar is None:
-            return ''
-        pv = ar.param_values
-        # if not pv.start_date or not pv.end_date:
-        #     return ''
-        events = self.events_by_course().order_by('start_date')
-        events = rt.models.system.PeriodEvents.started.add_filter(events, pv)
-        return "TODO: copy logic from presence_sheet.wk.html"
+    # @dd.virtualfield(dd.HtmlBox(_("Presences")))
+    # def presences_box(self, ar):
+    #     # not finished
+    #     if ar is None:
+    #         return ''
+    #     pv = ar.param_values
+    #     # if not pv.start_date or not pv.end_date:
+    #     #     return ''
+    #     events = self.events_by_course().order_by('start_date')
+    #     events = rt.models.system.PeriodEvents.started.add_filter(events, pv)
+    #     return "TODO: copy logic from presence_sheet.wk.html"
 
 
 
-# customize fields coming from mixins to override their inherited
-# default verbose_names
+# we want to use default values from the activity line
 dd.update_field(Course, 'every_unit', default=models.NOT_PROVIDED)
 dd.update_field(Course, 'every', default=models.NOT_PROVIDED)
 
@@ -542,7 +536,7 @@ class Enrolment(UserAuthored, Certifiable, DateRange):
         verbose_name_plural = _('Enrolments')
         unique_together = ('course', 'pupil')
 
-    course_area = CourseAreas.field(blank=True, editable=False)
+    course_area = ActivityLayouts.field(blank=True, editable=False)
 
     quick_search_fields = pupil_name_fields
 
@@ -599,16 +593,20 @@ class Enrolment(UserAuthored, Certifiable, DateRange):
         Called when an unknown pupil name was given.
         Try to auto-create it.
         """
+
+    def create_pupil_choice(self, text):
         Pupil = dd.resolve_model(pupil_model)
-        kw = parse_name(text)
-        if len(kw) != 2:
-            raise ValidationError(
-                "Cannot find first and last names in %r to \
-                auto-create pupil", text)
-        p = Pupil(**kw)
-        p.full_clean()
-        p.save()
-        return p
+        return Pupil.create_from_choice(text)
+
+        # kw = parse_name(text)
+        # if len(kw) != 2:
+        #     raise ValidationError(
+        #         "Cannot find first and last names in %r to \
+        #         auto-create pupil", text)
+        # p = Pupil(**kw)
+        # p.full_clean()
+        # p.save()
+        # return p
 
     @dd.chooser()
     def option_choices(cls, course):
@@ -624,7 +622,7 @@ class Enrolment(UserAuthored, Certifiable, DateRange):
 
     def get_confirm_veto(self, ar):
         """Called from :class:`ConfirmEnrolment
-        <lino_xl.lib.courses.workflows.ConfirmEnrolment>`.  If this
+        <lino_xl.lib.courses.workflows.std.ConfirmEnrolment>`.  If this
         returns something else than `None`, then the enrolment won't
         be confirmed and the return value will be displayed to the
         user.
@@ -639,7 +637,8 @@ class Enrolment(UserAuthored, Certifiable, DateRange):
 
     def get_guest_role(self):
         if self.course.line:
-            return self.course.line.guest_role
+            return self.course.line.guest_role or settings.SITE.site_config.pupil_guestrole
+        return settings.SITE.pupil_guestrole
 
     def make_guest_for(self, event):
         if not self.state.uses_a_place:
